<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Ticker - AEM Component Documentation</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 40px;
            line-height: 1.6;
        }
        h1 {
            color: blue;
        }
        ul {
            list-style-type: disc;
            margin-left: 20px;
        }
        .dialog-properties {
            border: 1px solid #ddd;
            padding: 15px;
            border-radius: 5px;
            background-color: #f9f9f9;
        }
        .dialog-properties ol {
            margin-left: 20px;
        }
    </style>
</head>
<body>
    <h1>Ticker - AEM Component Documentation</h1>
    <h2>Overview</h2>
    <p>The Ticker component is a custom AEM component that provides a scrolling ticker-style display, allowing users to showcase dynamic text and images in an engaging manner.</p>
    <h2>Features</h2>
    <ul>
        <li>Autoplay functionality for automatic scrolling.</li>
        <li>Navigation buttons for manual scrolling.</li>
        <li>Close button to remove the ticker from view.</li>
        <li>Customizable text, images, and styles.</li>
        <li>Flexible icon and title styling options.</li>
    </ul>    
    <h2>Functionality</h2>
    <ul>
        <li>Users can add multiple ticker items consisting of text and images.</li>
        <li>The ticker can be configured to autoplay or be navigated manually.</li>
        <li>Customization options for title, icons, borders, colors, and layout.</li>
    </ul>    
    <h2>Dialog Properties</h2>
    <div class="dialog-properties">
        <h3>1. General Configuration</h3>
        <ul>
            <li><strong>Title</strong> – Option to add a title.</li>
            <li><strong>Title Icon</strong> – Option to add an icon along with the title.</li>
            <li><strong>Autoplay</strong> – Option to enable autoplay for ticker items.</li>
            <li><strong>Navigation</strong> – Option to enable navigation buttons on the right.</li>
            <li><strong>Close Button</strong> – Option to enable the close button on the right.</li>
        </ul>        
        <h3>2. Items Configuration</h3>
        <ul>
            <li><strong>Items (MultiField)</strong> – Option to add multiple ticker items.
                <ul>
                    <li><strong>Item Text</strong> – Option to add text content.</li>
                    <li><strong>Item Image</strong> – Option to add an image next to the text.</li>
                </ul>
            </li>
        </ul>        
        <h3>3. Icon Style Configuration</h3>
        <ul>
            <li><strong>Icon Size</strong> – Set icon size.</li>
            <li><strong>Color</strong> – Set icon color.</li>
            <li><strong>Background Color</strong> – Set background color for the icon.</li>
            <li><strong>Margin</strong> – Set margin for the icon.</li>
            <li><strong>Boxed</strong> – Enable boxed property for the icon.</li>
            <li><strong>Box Size</strong> – Set size of the icon box.</li>
            <li><strong>Border Type</strong> – Set border type for the icon box.</li>
            <li><strong>Border Width</strong> – Set border width.</li>
            <li><strong>Border Radius</strong> – Set border radius.</li>
            <li><strong>Border Color</strong> – Set border color.</li>
        </ul>        
        <h3>4. Title Style Configuration</h3>
        <ul>
            <li><strong>Tag</strong> – Set tag for the title.</li>
            <li><strong>Font Color</strong> – Set color for the title.</li>
            <li><strong>Background Color</strong> – Set background color for the title.</li>
            <li><strong>Border Style</strong> – Set border style.</li>
            <li><strong>Border Color</strong> – Set border color.</li>
            <li><strong>Border Radius</strong> – Set border radius.</li>
            <li><strong>Border Width</strong> – Set border width.</li>
            <li><strong>Padding</strong> – Set padding.</li>
        </ul>        
        <h3>5. Text Image Style Configuration</h3>
        <ul>
            <li><strong>Size</strong> – Set size for the image.</li>
            <li><strong>Border Radius</strong> – Set border radius.</li>
            <li><strong>Left Margin</strong> – Set left margin.</li>
            <li><strong>Right Margin</strong> – Set right margin.</li>
        </ul>        
        <h3>6. Text Style Configuration</h3>
        <ul>
            <li><strong>Tag</strong> – Set tag for text.</li>
            <li><strong>Color</strong> – Set text color.</li>
            <li><strong>Background Color</strong> – Set background color for text.</li>
            <li><strong>Padding</strong> – Set padding.</li>
            <li><strong>Margin</strong> – Set margin.</li>
        </ul>        
        <h3>7. Navigation Style Configuration</h3>
        <ul>
            <li><strong>Arrow Previous</strong> – Option to add a previous navigation icon.</li>
            <li><strong>Arrow Next</strong> – Option to add a next navigation icon.</li>
            <li><strong>Size</strong> – Set navigation icon size.</li>
            <li><strong>Color</strong> – Set icon color.</li>
            <li><strong>Space Between Arrows</strong> – Set space between icons.</li>
            <li><strong>Boxed</strong> – Enable boxed property for navigation icons.</li>
        </ul>
    </div>    
    <h2>Usage Instructions</h2>
    <ol>
        <li>Add the component to an AEM page.</li>
        <li>Configure images and content for each ticker item.</li>
        <li>Customize styling and effects as needed.</li>
        <li>Preview and publish to activate the ticker.</li>
    </ol>    
    <h2>Additional Notes</h2>
    <ul>
        <li>Ensure images are optimized for better performance.</li>
        <li>Choose appropriate styling to enhance readability.</li>
    </ul>    
    <h2>Conclusion</h2>
    <p>The Ticker component adds an engaging scrolling effect to AEM pages, allowing dynamic content display with extensive customization options.</p>
</body>
</html>

